import { cleanupOutdatedCaches, precacheAndRoute } from "workbox-precaching";
import { clientsClaim } from "workbox-core";
import { dispatchCall, isJSONRPCCall, type Call } from "./workerrpc";

function isServiceWorker(
  self: WorkerGlobalScope,
  // @ts-ignore: workaround for workbox logger.d.ts decl
): self is ServiceWorkerGlobalScope {
  return (
    (self as unknown as Record<string, unknown>)["serviceWorker"] instanceof
    ServiceWorker
  );
}

if (!isServiceWorker(self)) {
  throw new TypeError("This entry point must be run in a service worker");
}

cleanupOutdatedCaches();
precacheAndRoute(self.__WB_MANIFEST, {
  cleanURLs: false,
});

// auto update
self.skipWaiting();
clientsClaim();

export const Service = {
  ping() {},
};

self.addEventListener("message", (event: MessageEvent<unknown>) => {
  const payload = event.data;
  if (typeof payload !== "object") return;
  if (isJSONRPCCall(payload as Record<string, unknown>)) {
    dispatchCall(
      Service,
      event as MessageEvent<Call<unknown>> & { source: MessageEventSource },
    );
  }
});
